@@ -481,12 +481,6 @@ def pathlookup(
             "type": "text",
             "label": "Destination IP",
         },
-        {
-            "type": "select",
-            "label": "Protocol",
-            "choices": protocols,
-            "default": protocols[0],
-        },
         {
             "type": "text",
             "label": "Source Ports",
@@ -497,6 +491,12 @@ def pathlookup(
             "label": "Destination Ports",
             "default": "22",
         },
+        {
+            "type": "select",
+            "label": "Protocol",
+            "choices": protocols,
+            "default": protocols[0],
+        },
     ]
 
     if not all([src_ip, dst_ip, src_port, dst_port, protocol]):
@@ -689,7 +689,7 @@ def wireless(dispatcher, option=None, ssid=None):
     """Get wireless information by client or ssid."""
     snapshot_id = get_user_snapshot(dispatcher)
     logger.debug("Getting SSIDs")
-    ssids = [(ssidi["wlanSsid"].lower()) for ssidi in ipfabric_api.get_wireless_ssids(snapshot_id)]
+    ssids = ipfabric_api.get_wireless_ssids(snapshot_id)
 
     if not ssids:
         dispatcher.send_blocks(
@@ -722,7 +722,7 @@ def wireless(dispatcher, option=None, ssid=None):
 
 def get_wireless_ssids(dispatcher, ssid=None, snapshot_id=None):
     """Get All Wireless SSID Information."""
-    ssids = [(ssid_["wlanSsid"].lower()) for ssid_ in ipfabric_api.get_wireless_ssids(snapshot_id)]
+    ssids = ipfabric_api.get_wireless_ssids(snapshot_id)
     if not ssids:
         dispatcher.send_blocks(
             [
@@ -738,8 +738,6 @@ def get_wireless_ssids(dispatcher, ssid=None, snapshot_id=None):
         )
         return True
 
-    ssids = ipfabric_api.get_wireless_ssids(snapshot_id)
-
     dispatcher.send_blocks(
         [
             *dispatcher.command_response_header(
@@ -781,6 +779,7 @@ def get_wireless_clients(dispatcher, ssid=None, snapshot_id=None):
     ssids = [
         (f"{ssid_['wlanSsid']}-{ssid_['radioDscr']}", ssid_["wlanSsid"])
         for ssid_ in ipfabric_api.get_wireless_ssids(snapshot_id)
+        if ssid_["wlanSsid"]
     ]
     if not ssids:
         dispatcher.send_blocks(
